@@ -56,7 +56,12 @@ class InstallLabExtensionApp(BaseExtensionApp):
         [install_extension(arg, self.app_dir, logger=self.log)
          for arg in self.extra_args]
         if self.should_build:
-            build(self.app_dir, logger=self.log)
+            try:
+                build(self.app_dir, logger=self.log)
+            except Exception as e:
+                for arg in self.extra_args:
+                    uninstall_extension(arg, self.app_dir, logger=self.log)
+                raise e
 
 
 class LinkLabExtensionApp(BaseExtensionApp):
@@ -76,7 +81,12 @@ class LinkLabExtensionApp(BaseExtensionApp):
         [link_package(arg, self.app_dir, logger=self.log)
          for arg in self.extra_args]
         if self.should_build:
-            build(self.app_dir, logger=self.log)
+            try:
+                build(self.app_dir, logger=self.log)
+            except Exception as e:
+                for arg in self.extra_args:
+                    unlink_package(arg, self.app_dir, logger=self.log)
+                raise e
 
 
 class UnlinkLabExtensionApp(BaseExtensionApp):
@@ -112,15 +122,6 @@ class ListLabExtensionsApp(BaseExtensionApp):
         list_extensions(self.app_dir, logger=self.log)
 
 
-class ListLinkedLabExtensionsApp(BaseExtensionApp):
-    description = "List the linked packages"
-
-    def start(self):
-        linked = _get_linked_packages(self.app_dir, logger=self.log)
-        for path in linked.values():
-            print(path)
-
-
 class EnableLabExtensionsApp(BaseExtensionApp):
     description = "Enable labextension(s) by name"
 
@@ -157,7 +158,6 @@ class LabExtensionApp(JupyterApp):
         list=(ListLabExtensionsApp, "List labextensions"),
         link=(LinkLabExtensionApp, "Link labextension(s)"),
         unlink=(UnlinkLabExtensionApp, "Unlink labextension(s)"),
-        listlinked=(ListLinkedLabExtensionsApp, "List linked extensions"),
         enable=(EnableLabExtensionsApp, "Enable labextension(s)"),
         disable=(DisableLabExtensionsApp, "Disable labextensions(s)")
     )
